pub(crate) fn toward_xml(
env: Envelope,
schema: &Schema,
) -> Result<Envelope, String>Expand description
Converts env to UCI XML when it is OMS JSON.
Already-XML payloads are labelled and returned. The type hint is
replaced with the converted message name. A-GRA EncodedPayload
hex is converted the same way as the wrapper.
Errors
Returns a message if the bytes are not UTF-8, the JSON will not parse as a UCI message, or the inner hex cannot be transcoded.